@@ -1,4 +1,7 @@
 #include <H5FDpublic.h>
+#if H5_VERSION_GE(1,14,0)
+#include <H5FDdevelop.h>
+#endif
 
 #include <string.h>
 
@@ -11,4 +14,4 @@
 
 BC_INLINE_ARRAY(H5FD_FLMAP_SINGLE,      H5FD_mem_t)
 BC_INLINE_ARRAY(H5FD_FLMAP_DICHOTOMY,   H5FD_mem_t)
-BC_INLINE_ARRAY(H5FD_FLMAP_DEFAULT,     H5FD_mem_t)
\ No newline at end of file
+BC_INLINE_ARRAY(H5FD_FLMAP_DEFAULT,     H5FD_mem_t)
